/* -*-c-*-
 *
 * $Id: rxglue.h,v 1.1 2002/01/25 19:34:45 mdw Exp $
 *
 * REXX glue for C core functionality
 *
 * (c) 2001 Mark Wooding
 */

/*----- Licensing notice --------------------------------------------------* 
 *
 * This file is part of Jog: Programming for a jogging machine.
 *
 * Jog is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 * 
 * Jog is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Jog; if not, write to the Free Software Foundation,
 * Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

/*----- Revision history --------------------------------------------------* 
 *
 * $Log: rxglue.h,v $
 * Revision 1.1  2002/01/25 19:34:45  mdw
 * Initial revision
 *
 */

#ifndef RXGLUE_H
#define RXGLUE_H

#ifdef __cplusplus
  extern "C" {
#endif

/*----- Header files ------------------------------------------------------*/

#ifdef HAVE_CONFIG_H
#  include "config.h"
#endif

#include <stddef.h>

/*----- Functions provided ------------------------------------------------*/

/* --- @rx_run@ --- *
 *
 * Arguments:	@const char *name@ = pointer to filename (or null)
 *		@const void *p@ = pointer to program text
 *		@size_t sz@ = size of program text
 *		@int ac@ = number of arguments
 *		@const char *const *av@ = vector of command-line arguments
 *
 * Returns:	Exit code from program.
 *
 * Use:		Runs a REXX script from memory.
 */

extern int rx_run(const char */*name*/, const void */*p*/, size_t /*sz*/,
		  int /*ac*/, const char *const */*av*/);

/* --- @rx_runfile@ --- *
 *
 * Arguments:	@const char *name@ = pointer to filename
 *		@int ac@ = number of command-line arguments
 *		@const char *const *av@ = vector of command-line arguments
 *
 * Returns:	Exit code from program.
 *
 * Use:		Runs a REXX script from a file, given its name.
 */

extern int rx_runfile(const char */*name*/,
		      int /*ac*/, const char *const */*av*/);

/* --- @rx_init@ --- *
 *
 * Arguments:	---
 *
 * Returns:	---
 *
 * Use:		Initializes the REXX external functions.
 */

extern void rx_init(void);

/*----- That's all, folks -------------------------------------------------*/

#ifdef __cplusplus
  }
#endif

#endif
